# Test Coverage Report: excluded packages and modules

Generated: Thu 2013-02-28 14:37 SGT

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- django.contrib.admin
- django.contrib.admindocs
- django.contrib.auth
- django.contrib.contenttypes
- django.contrib.messages
- django.contrib.sessions
- django.contrib.sitemaps
- django.contrib.sites
- django.contrib.staticfiles
- subscribe.admin
- subscribe.migrations
- subscribe.templatetags.__init__
- subscribe.tests
- subscribe.tests.test_app.__init__
- subscribe.urls

Back to index.